==> onednn-1.4-1-x86_64.pkg.tar.zst: usr/share/doc/dnnl/reference/html/search/all_0.js <==
var searchData=
[
  ['a_0',['a',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa0cc175b9c0f1b6a831c399e269772661',1,'dnnl::memory']]],
  ['ab_1',['ab',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa187ef4436122d1cc2f40dc2b92f0eba0',1,'dnnl::memory']]],
  ['abc_2',['abc',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa900150983cd24fb0d6963f7d28e17f72',1,'dnnl::memory']]],
  ['abcd_3',['abcd',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fae2fc714c4727ee9395f324cd2e7f331f',1,'dnnl::memory']]],
  ['abcd8b_4',['aBcd8b',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa448a7fc9219294ce172b0edf9498b5c4',1,'dnnl::memory']]],
  ['abcd8b8a_5',['ABcd8b8a',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fabcbce50e9c241458767871fa053e1ba0',1,'dnnl::memory']]],
  ['abcde_6',['abcde',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3faab56b4d92b40713acc5af89985d4b786',1,'dnnl::memory']]],
  ['abcdef_7',['abcdef',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fae80b5017098950fc58aad83c8c14978e',1,'dnnl::memory']]],
  ['abdc_8',['abdc',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa5e822a0b52c71ce2ff2ecd3aa8ca46fc',1,'dnnl::memory']]],
  ['abdec_9',['abdec',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa7a05226d93263d6fc613f52400f7416d',1,'dnnl::memory']]],
  ['acb_10',['acb',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa5ff832d9bca8241d653279756f3ccd11',1,'dnnl::memory']]],
  ['acbde_11',['acbde',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fae0e56a95aff0ee48fc44e8a4faf69adb',1,'dnnl::memory']]],
  ['acbdef_12',['acbdef',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa66fd87374b1ec6be9fdbea534e17adeb',1,'dnnl::memory']]],
  ['accum_5fdata_5ftype_13',['accum_data_type',['../structdnnl__convolution__desc__t.html#a09ca2f54dc7a24ab71ab3e178f519dcd',1,'dnnl_convolution_desc_t::accum_data_type()'],['../structdnnl__pooling__desc__t.html#add70bfb59910284ac5600554560c8e55',1,'dnnl_pooling_desc_t::accum_data_type()'],['../structdnnl__inner__product__desc__t.html#a8fd7ff28b94fc9d485371536f6a2a1c8',1,'dnnl_inner_product_desc_t::accum_data_type()'],['../structdnnl__matmul__desc__t.html#aff9853c7aee532d6baca81c4ee8ab810',1,'dnnl_matmul_desc_t::accum_data_type()']]],
  ['acdb_14',['acdb',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa776649ab3d00664587b889457db87da7',1,'dnnl::memory']]],
  ['acdeb_15',['acdeb',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3faf95d333a023ac787b43babc5b5c480ae',1,'dnnl::memory']]],
  ['activation_5fkind_16',['activation_kind',['../structdnnl__rnn__desc__t.html#ac25cfdc16c19ba5d2b3c1eba086e8a75',1,'dnnl_rnn_desc_t']]],
  ['alg_5fkind_17',['alg_kind',['../structdnnl__convolution__desc__t.html#a9a82a0415d9052264a259dd3f9ccaaf1',1,'dnnl_convolution_desc_t::alg_kind()'],['../structdnnl__eltwise__desc__t.html#ae5d386bea1a4c651880ab304a7044fe4',1,'dnnl_eltwise_desc_t::alg_kind()'],['../structdnnl__pooling__desc__t.html#a6dc1371eb776111b66334f0f0aea2a4c',1,'dnnl_pooling_desc_t::alg_kind()'],['../structdnnl__lrn__desc__t.html#ac85e412ee28f0318187b361c9bb8785c',1,'dnnl_lrn_desc_t::alg_kind()'],['../structdnnl__binary__desc__t.html#a7de6b0ea07d03866df649802405a7918',1,'dnnl_binary_desc_t::alg_kind()'],['../structdnnl__resampling__desc__t.html#a21f709d07bd16a1925d2d7e1ef643677',1,'dnnl_resampling_desc_t::alg_kind()']]],
  ['algorithm_18',['algorithm',['../group__dnnl__api__attributes.html#ga00377dd4982333e42e8ae1d09a309640',1,'dnnl']]],
  ['all_19',['all',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa181a603769c1f98ad927e7367c7aa51',1,'dnnl']]],
  ['alpha_20',['alpha',['../structdnnl__eltwise__desc__t.html#a10784684fa814edcb365c0a8fecdef59',1,'dnnl_eltwise_desc_t']]],
  ['any_21',['any',['../structdnnl_1_1engine.html#a2635da16314dcbdb9bd9ea431316bb1aa100b8cad7cf2a56f6df78f171f97a1ec',1,'dnnl::engine::any()'],['../structdnnl_1_1memory.html#aabcadfb0e23a36a91272fc571cff105fa100b8cad7cf2a56f6df78f171f97a1ec',1,'dnnl::memory::any()'],['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa100b8cad7cf2a56f6df78f171f97a1ec',1,'dnnl::memory::any()']]],
  ['append_5fdw_5fk3s1p1_22',['append_dw_k3s1p1',['../structdnnl_1_1post__ops.html#a4229db0e1e1eab273ed0e2b3e18402de',1,'dnnl::post_ops']]],
  ['append_5fdw_5fk3s2p1_23',['append_dw_k3s2p1',['../structdnnl_1_1post__ops.html#a88ed886c27b4df4667431ed48d29f4c1',1,'dnnl::post_ops']]],
  ['append_5feltwise_24',['append_eltwise',['../structdnnl_1_1post__ops.html#a66606f08467b19091e696b52a2f789e6',1,'dnnl::post_ops']]],
  ['append_5fsum_25',['append_sum',['../structdnnl_1_1post__ops.html#a078ab8ec15423d2b3d26f3619a78ca38',1,'dnnl::post_ops']]],
  ['arg_26',['arg',['../structdnnl__exec__arg__t.html#a46c7f77870713b8af3fd37dc66e9690b',1,'dnnl_exec_arg_t']]],
  ['asynchronous_27',['ASYNCHRONOUS',['../structdnnl_1_1threadpool__iface.html#a740361555b71b3ddd2f740c8e0bcfdba',1,'dnnl::threadpool_iface']]],
  ['avx_28',['avx',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a73758c37e4499f20ac5f995a144abba6',1,'dnnl']]],
  ['avx2_29',['avx2',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a220c4ad92e33497ef256a48712352b84',1,'dnnl']]],
  ['avx512_5fcore_30',['avx512_core',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa427cc9f00ac692056a83a8cb5e37fa4',1,'dnnl']]],
  ['avx512_5fcore_5fbf16_31',['avx512_core_bf16',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83af9b353b49d5aa4dfe76e22337b5a02cf',1,'dnnl']]],
  ['avx512_5fcore_5fvnni_32',['avx512_core_vnni',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83acac6fe12844735aafd8fd1fd81738f8e',1,'dnnl']]],
  ['avx512_5fmic_33',['avx512_mic',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a046d44270c4d1f4f1c76ae337c97ccf3',1,'dnnl']]],
  ['avx512_5fmic_5f4ops_34',['avx512_mic_4ops',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aad1ffde9d0e65a434da74d86c82f1edd',1,'dnnl']]],
  ['axis_35',['axis',['../structdnnl__shuffle__desc__t.html#a1bb136f69743fc7381990f4406bf7fe2',1,'dnnl_shuffle_desc_t']]],
  ['api_36',['API',['../dev_guide_c_and_cpp_apis.html',1,'']]],
  ['attributes_37',['Attributes',['../group__dnnl__api__attributes.html',1,'']]]
];

==> onednn-1.6.1-1-x86_64.pkg.tar.zst: usr/share/doc/dnnl/reference/html/search/all_0.js <==
var searchData=
[
  ['a_0',['a',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa0cc175b9c0f1b6a831c399e269772661',1,'dnnl::memory']]],
  ['ab_1',['ab',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa187ef4436122d1cc2f40dc2b92f0eba0',1,'dnnl::memory']]],
  ['abc_2',['abc',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa900150983cd24fb0d6963f7d28e17f72',1,'dnnl::memory']]],
  ['abcd_3',['abcd',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fae2fc714c4727ee9395f324cd2e7f331f',1,'dnnl::memory']]],
  ['abcd8b_4',['aBcd8b',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa448a7fc9219294ce172b0edf9498b5c4',1,'dnnl::memory']]],
  ['abcd8b8a_5',['ABcd8b8a',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fabcbce50e9c241458767871fa053e1ba0',1,'dnnl::memory']]],
  ['abcde_6',['abcde',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3faab56b4d92b40713acc5af89985d4b786',1,'dnnl::memory']]],
  ['abcdef_7',['abcdef',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fae80b5017098950fc58aad83c8c14978e',1,'dnnl::memory']]],
  ['abdc_8',['abdc',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa5e822a0b52c71ce2ff2ecd3aa8ca46fc',1,'dnnl::memory']]],
  ['abdec_9',['abdec',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa7a05226d93263d6fc613f52400f7416d',1,'dnnl::memory']]],
  ['acb_10',['acb',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa5ff832d9bca8241d653279756f3ccd11',1,'dnnl::memory']]],
  ['acbde_11',['acbde',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fae0e56a95aff0ee48fc44e8a4faf69adb',1,'dnnl::memory']]],
  ['acbdef_12',['acbdef',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa66fd87374b1ec6be9fdbea534e17adeb',1,'dnnl::memory']]],
  ['accum_5fdata_5ftype_13',['accum_data_type',['../structdnnl__convolution__desc__t.html#a09ca2f54dc7a24ab71ab3e178f519dcd',1,'dnnl_convolution_desc_t::accum_data_type()'],['../structdnnl__pooling__desc__t.html#add70bfb59910284ac5600554560c8e55',1,'dnnl_pooling_desc_t::accum_data_type()'],['../structdnnl__inner__product__desc__t.html#a8fd7ff28b94fc9d485371536f6a2a1c8',1,'dnnl_inner_product_desc_t::accum_data_type()'],['../structdnnl__matmul__desc__t.html#aff9853c7aee532d6baca81c4ee8ab810',1,'dnnl_matmul_desc_t::accum_data_type()']]],
  ['acdb_14',['acdb',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa776649ab3d00664587b889457db87da7',1,'dnnl::memory']]],
  ['acdeb_15',['acdeb',['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3faf95d333a023ac787b43babc5b5c480ae',1,'dnnl::memory']]],
  ['activation_5fkind_16',['activation_kind',['../structdnnl__rnn__desc__t.html#ac25cfdc16c19ba5d2b3c1eba086e8a75',1,'dnnl_rnn_desc_t']]],
  ['alg_5fkind_17',['alg_kind',['../structdnnl__convolution__desc__t.html#a9a82a0415d9052264a259dd3f9ccaaf1',1,'dnnl_convolution_desc_t::alg_kind()'],['../structdnnl__eltwise__desc__t.html#ae5d386bea1a4c651880ab304a7044fe4',1,'dnnl_eltwise_desc_t::alg_kind()'],['../structdnnl__pooling__desc__t.html#a6dc1371eb776111b66334f0f0aea2a4c',1,'dnnl_pooling_desc_t::alg_kind()'],['../structdnnl__lrn__desc__t.html#ac85e412ee28f0318187b361c9bb8785c',1,'dnnl_lrn_desc_t::alg_kind()'],['../structdnnl__binary__desc__t.html#a7de6b0ea07d03866df649802405a7918',1,'dnnl_binary_desc_t::alg_kind()'],['../structdnnl__resampling__desc__t.html#a21f709d07bd16a1925d2d7e1ef643677',1,'dnnl_resampling_desc_t::alg_kind()']]],
  ['algorithm_18',['algorithm',['../group__dnnl__api__attributes.html#ga00377dd4982333e42e8ae1d09a309640',1,'dnnl']]],
  ['all_19',['all',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa181a603769c1f98ad927e7367c7aa51',1,'dnnl']]],
  ['alpha_20',['alpha',['../structdnnl__eltwise__desc__t.html#a10784684fa814edcb365c0a8fecdef59',1,'dnnl_eltwise_desc_t']]],
  ['any_21',['any',['../structdnnl_1_1engine.html#a2635da16314dcbdb9bd9ea431316bb1aa100b8cad7cf2a56f6df78f171f97a1ec',1,'dnnl::engine::any()'],['../structdnnl_1_1memory.html#aabcadfb0e23a36a91272fc571cff105fa100b8cad7cf2a56f6df78f171f97a1ec',1,'dnnl::memory::any()'],['../structdnnl_1_1memory.html#a8e71077ed6a5f7fb7b3e6e1a5a2ecf3fa100b8cad7cf2a56f6df78f171f97a1ec',1,'dnnl::memory::any()']]],
  ['append_5fdw_5fk3s1p1_22',['append_dw_k3s1p1',['../structdnnl_1_1post__ops.html#a4229db0e1e1eab273ed0e2b3e18402de',1,'dnnl::post_ops']]],
  ['append_5fdw_5fk3s2p1_23',['append_dw_k3s2p1',['../structdnnl_1_1post__ops.html#a88ed886c27b4df4667431ed48d29f4c1',1,'dnnl::post_ops']]],
  ['append_5feltwise_24',['append_eltwise',['../structdnnl_1_1post__ops.html#a28460923ad579c780e4027a6256fe207',1,'dnnl::post_ops']]],
  ['append_5fsum_25',['append_sum',['../structdnnl_1_1post__ops.html#ab8e3832e8600216a3646e9050d3bc1f3',1,'dnnl::post_ops']]],
  ['arg_26',['arg',['../structdnnl__exec__arg__t.html#a46c7f77870713b8af3fd37dc66e9690b',1,'dnnl_exec_arg_t']]],
  ['asynchronous_27',['ASYNCHRONOUS',['../structdnnl_1_1threadpool__iface.html#a740361555b71b3ddd2f740c8e0bcfdba',1,'dnnl::threadpool_iface']]],
  ['avx_28',['avx',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a73758c37e4499f20ac5f995a144abba6',1,'dnnl']]],
  ['avx2_29',['avx2',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a220c4ad92e33497ef256a48712352b84',1,'dnnl']]],
  ['avx512_5fcore_30',['avx512_core',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aa427cc9f00ac692056a83a8cb5e37fa4',1,'dnnl']]],
  ['avx512_5fcore_5famx_31',['avx512_core_amx',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83ad49189665b06a3259b3bf3603319fd0d',1,'dnnl']]],
  ['avx512_5fcore_5fbf16_32',['avx512_core_bf16',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83af9b353b49d5aa4dfe76e22337b5a02cf',1,'dnnl']]],
  ['avx512_5fcore_5fvnni_33',['avx512_core_vnni',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83acac6fe12844735aafd8fd1fd81738f8e',1,'dnnl']]],
  ['avx512_5fmic_34',['avx512_mic',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83a046d44270c4d1f4f1c76ae337c97ccf3',1,'dnnl']]],
  ['avx512_5fmic_5f4ops_35',['avx512_mic_4ops',['../group__dnnl__api__service.html#ggabad017feb1850634bf3babdb68234f83aad1ffde9d0e65a434da74d86c82f1edd',1,'dnnl']]],
  ['axis_36',['axis',['../structdnnl__shuffle__desc__t.html#a1bb136f69743fc7381990f4406bf7fe2',1,'dnnl_shuffle_desc_t']]],
  ['api_37',['API',['../dev_guide_c_and_cpp_apis.html',1,'']]],
  ['attributes_38',['Attributes',['../group__dnnl__api__attributes.html',1,'']]]
];
